LockoutMode

Enum LockoutMode 

pub enum LockoutMode {
    Off = 0,
    On = 1,
    Group = 2,
}
Channel lockout mode for scan operations.

Maps to the lockout field in the ME command.

Per User Manual Chapter 9: lockout can be set individually for all 1000 memory channels but cannot be set for program scan memory (L0/U0 through L49/U49). The lockout icon appears to the right of the channel number when a locked-out channel is recalled. Lockout cannot be toggled in VFO or CALL channel mode.

Variants



Off = 0

Not locked out (index 0).



On = 1

Locked out of scan (index 1).



Group = 2

Group lockout (index 2).

Implementations

Source

impl LockoutMode

pub const COUNT: u8 = 3

Number of valid lockout mode values (0-2).